@@ -146,6 +146,14 @@ sub cmd_populate {
     ->populate(@{$self->fixture_sets});
 }
 
+sub cmd_help {
+  my ($self, $subhelp) = @_;
+  die "Help not yet finished.";
+  if($subhelp) {
+  } else {
+  }
+}
+
 sub _import_libs {
   my ($self, @libs) = @_;
   require lib;
@@ -164,11 +172,13 @@ sub run {
   $self->_import_libs(@{$self->includes})
     if $self->has_includes;
 
-  die "Must supply a command\n" unless $cmd;
-  die "Extra argv detected - command only please\n" if @extra_argv;
-  die "No such command ${cmd}\n" unless $self->can("cmd_${cmd}");
-
-  $self->${\"cmd_${cmd}"};
+  if(!$cmd || $cmd eq 'help') {
+    $self->cmd_help(@extra_argv);
+  } else {
+    die "Extra argv detected - command only please\n" if @extra_argv;
+    die "No such command ${cmd}\n" unless $self->can("cmd_${cmd}");
+    $self->${\"cmd_${cmd}"};
+  }
 }
 
 sub run_with_options {
@@ -288,8 +298,8 @@ Accepts Str.  Not Required
 This is the DSN for the database you are going to be targeting for deploying
 or altering ddl, and installing or generating fixtures.
 
-This should be a DSN suitable for L<DBIx::Class::Schema/connect), something
-in the form of C<DBI:SQLite:myapp-schema.db)>.
+This should be a DSN suitable for L<DBIx::Class::Schema/connect>, something
+in the form of C<DBI:SQLite:myapp-schema.db>.
 
 Please take care where you point this (like production :) )
 
@@ -405,7 +415,7 @@ Should point to the class that does what L<DBIx::Class::Migration> does.  This
 is exposed here for those who need to subclass L<DBIx::Class::Migration>.  We
 don't expose this attribute to the commandline, so if you are smart enough to
 do the subclassing (and sure you need to do that), I will assume you will also
-either subclass L<L<DBIx::Class::Migration:Script> or override then default
+either subclass L<DBIx::Class::Migration:Script> or override then default
 value using some standard technique.
 
 =head2 dbic_fixture_class
